abacusai.leakage_duplication — AbacusAI documentation

# `abacusai.leakage_duplication`

## Module Contents

### Classes

`LeakageDuplication` | Leakage detection for duplication within data

class abacusai.leakage_duplication.LeakageDuplication(client, totalCount=None, numDuplicates=None, sample={})

  Bases: `abacusai.return_class.AbstractApiClass`

  Leakage detection for duplication within data

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - totalCount (int) – Total count of rows in data.

    - numDuplicates (int) – Number of Duplicates based on primary keys in data.

    - sample (FeatureRecord) – A list of dicts enumerating rows the rows that contained duplications in primary keys.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict